==> jc-1.4.0.tar.gz: gnu/java/security/der/DER.h <==
// public abstract interface gnu.java.security.der.DER

// class file dependencies
// @dep_class c3c7f628c3880116 gnu_java_security_der_DER
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_der_DER_H_
#define _JC_gnu_java_security_der_DER_H_

// Typedefs
typedef struct _jc_gnu_java_security_der_DER$fields_struct	_jc_gnu_java_security_der_DER$fields_struct;
typedef const struct _jc_gnu_java_security_der_DER$vtype	_jc_gnu_java_security_der_DER$vtype;

// Class fields structure
struct _jc_gnu_java_security_der_DER$fields_struct {
	struct _jc_java_lang_Object$object	*CONSTRUCTED__5fVALUE;
	jint	ANY;
	jint	APPLICATION;
	jint	BIT__5fSTRING;
	jint	BMP__5fSTRING;
	jint	BOOLEAN;
	jint	CONSTRUCTED;
	jint	CONTEXT;
	jint	ENUMERATED;
	jint	GENERALIZED__5fTIME;
	jint	GENERAL__5fSTRING;
	jint	GRAPHIC__5fSTRING;
	jint	IA5__5fSTRING;
	jint	INTEGER;
	jint	ISO646__5fSTRING;
	jint	NULL;
	jint	NUMERIC__5fSTRING;
	jint	OBJECT__5fIDENTIFIER;
	jint	OCTET__5fSTRING;
	jint	PRINTABLE__5fSTRING;
	jint	PRIVATE;
	jint	REAL;
	jint	RELATIVE__5fOID;
	jint	SEQUENCE;
	jint	SET;
	jint	T61__5fSTRING;
	jint	UNIVERSAL;
	jint	UNIVERSAL__5fSTRING;
	jint	UTC__5fTIME;
	jint	UTF8__5fSTRING;
	jint	VIDEOTEX__5fSTRING;
};
extern _jc_gnu_java_security_der_DER$fields_struct _jc_gnu_java_security_der_DER$class_fields;

// Static methods
extern void _jc_gnu_java_security_der_DER$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_gnu_java_security_der_DER$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_gnu_java_security_der_DER$vtype _jc_gnu_java_security_der_DER$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_der_DER, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_der_DER$class_object;

#endif	/* _JC_gnu_java_security_der_DER_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/der/DER.h <==
// public abstract interface gnu.java.security.der.DER

// class file dependencies
// @dep_class c3c7f628c3880116 gnu_java_security_der_DER
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_der_DER_H_
#define _JC_gnu_java_security_der_DER_H_

// Typedefs
typedef struct _jc_gnu_java_security_der_DER$fields_struct	_jc_gnu_java_security_der_DER$fields_struct;
typedef const struct _jc_gnu_java_security_der_DER$vtype	_jc_gnu_java_security_der_DER$vtype;

// Class fields structure
struct _jc_gnu_java_security_der_DER$fields_struct {
	struct _jc_java_lang_Object$object	*CONSTRUCTED__5fVALUE;
	jint	ANY;
	jint	APPLICATION;
	jint	BIT__5fSTRING;
	jint	BMP__5fSTRING;
	jint	BOOLEAN;
	jint	CONSTRUCTED;
	jint	CONTEXT;
	jint	ENUMERATED;
	jint	GENERALIZED__5fTIME;
	jint	GENERAL__5fSTRING;
	jint	GRAPHIC__5fSTRING;
	jint	IA5__5fSTRING;
	jint	INTEGER;
	jint	ISO646__5fSTRING;
	jint	NULL;
	jint	NUMERIC__5fSTRING;
	jint	OBJECT__5fIDENTIFIER;
	jint	OCTET__5fSTRING;
	jint	PRINTABLE__5fSTRING;
	jint	PRIVATE;
	jint	REAL;
	jint	RELATIVE__5fOID;
	jint	SEQUENCE;
	jint	SET;
	jint	T61__5fSTRING;
	jint	UNIVERSAL;
	jint	UNIVERSAL__5fSTRING;
	jint	UTC__5fTIME;
	jint	UTF8__5fSTRING;
	jint	VIDEOTEX__5fSTRING;
};
extern _jc_gnu_java_security_der_DER$fields_struct _jc_gnu_java_security_der_DER$class_fields;

// Static methods
extern void _jc_gnu_java_security_der_DER$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_gnu_java_security_der_DER$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_gnu_java_security_der_DER$vtype _jc_gnu_java_security_der_DER$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_der_DER, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_der_DER$class_object;

#endif	/* _JC_gnu_java_security_der_DER_H_ */
